/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: enrollment
 * Version: 1.06.00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package fr.kosmos.selenium.inscription;

import org.testng.annotations.Test;

import fr.kosmos.selenium.annotation.Exigence;
import fr.kosmos.selenium.bean.ActualiteBean;
import fr.kosmos.selenium.bean.InscriptionBean;
import fr.kosmos.selenium.core.KSupTestCase;
import fr.kosmos.selenium.service.fiche.ServiceActualite;
import fr.kosmos.selenium.service.fiche.ServiceInscription;
import fr.kosmos.selenium.utils.DateUtils;
import fr.kosmos.selenium.utils.EnumExtension;
import fr.kosmos.selenium.utils.RoleTest;

/**
 * Suite de test liés à la création d'actualités
 * Created by mathis.abdelaziz on 20/12/17.
 */
public class ITInscriptionTestCase extends KSupTestCase {

    private ServiceActualite serviceActualite;

    private ActualiteBean actualiteBean;

    private ServiceInscription serviceInscription;

    public void initScreen() {
        serviceActualite = new ServiceActualite(this);
        serviceInscription = new ServiceInscription(this);
        actualiteBean = new ActualiteBean();
        actualiteBean.setRubrique("Inscription");
        actualiteBean.setRubriquePath(new String[] {"Site DATA", "Version française", "Navigation", "Modules et extensions"});
        actualiteBean.setTitre("Mon actualité pour test inscription");
    }

    @Test
    @Exigence(ticketExigence = "KRTO-568", ticketTest = "KRTO-1111", enTantQue = RoleTest.ADMIN, jeVeux = "Ecrire un nouvelle entrée inscription depuis la fiche actualite", afinDe = "Vérifier que le bouton d'inscription s'affiche en front office et que je puisse m'inscrire")
    public void testInscription() {
        actualiteBean.setInscription(fillInscriptionBean());
        serviceMenuBO.navigateToContenu(EnumExtension.ACTUALITE);
        serviceActualite.getScreenBO().createContent();
        serviceActualite.fillContent(actualiteBean);
        actualiteBean.getInscription().setInscriptionOuverte(false);
        serviceInscription.fillSpecificContent(actualiteBean.getInscription());
        serviceActualite.publishContent();
        serviceActualite.viewContentDatagrid(actualiteBean.getTitre());
        serviceInscription.controlFrontActualite(actualiteBean.getInscription());
    }

    @Test
    @Exigence(ticketExigence = "KRTO-565", ticketTest = "KRTO-1080", enTantQue = RoleTest.ADMIN, jeVeux = "Ecrire un nouvelle entrée inscription depuis la fiche actualite", afinDe = "Vérifier que le bouton d'inscription ne s'affiche plus l'inscription est close")
    public void testInscriptionClose() {
        actualiteBean.setInscription(fillInscriptionBeanClose());
        actualiteBean.setTitre("Actualité pour inscription Close");
        serviceMenuBO.navigateToContenu(EnumExtension.ACTUALITE);
        serviceActualite.getScreenBO().createContent();
        serviceActualite.fillContent(actualiteBean);
        serviceInscription.fillSpecificContent(actualiteBean.getInscription());
        serviceActualite.publishContent();
        serviceActualite.viewContentDatagrid(actualiteBean.getTitre());
        serviceInscription.controlInscriptionClose();
    }

    @Test
    @Exigence(ticketExigence = "KRTO-565", ticketTest = "KRTO-1108", enTantQue = RoleTest.ADMIN, jeVeux = "Ecrire un nouvelle entrée inscription depuis la fiche actualite", afinDe = "Vérifier que le bouton d'inscription ne s'affiche plus l'inscription est close car les dates sont dépassées")
    public void testInscriptionDateClose() {
        actualiteBean.setInscription(fillInscriptionBeanDateClose());
        actualiteBean.setTitre("Actualité pour inscription Close (date)");
        serviceMenuBO.navigateToContenu(EnumExtension.ACTUALITE);
        serviceActualite.getScreenBO().createContent();
        serviceActualite.fillContent(actualiteBean);
        serviceInscription.fillSpecificContent(actualiteBean.getInscription());
        serviceActualite.publishContent();
        serviceActualite.viewContentDatagrid(actualiteBean.getTitre());
        serviceInscription.controlInscriptionClose();
    }

    @Test
    @Exigence(ticketExigence = "KRTO-565", ticketTest = "KRTO-1156", enTantQue = RoleTest.ADMIN, jeVeux = "Ecrire un nouvelle entrée inscription depuis la fiche actualite", afinDe = "Vérifier que le bouton d'inscription ne s'affiche plus l'inscription est close car les dates sont dépassées")
    public void testInscriptionMaxPlaceReached() {
        actualiteBean.setInscription(fillInscriptionBeanMaxReached());
        actualiteBean.setTitre("Actualité pour max place");
        serviceMenuBO.navigateToContenu(EnumExtension.ACTUALITE);
        serviceActualite.getScreenBO().createContent();
        serviceActualite.fillContent(actualiteBean);
        serviceInscription.fillSpecificContent(actualiteBean.getInscription());
        serviceActualite.publishContent();
        serviceActualite.viewContentDatagrid(actualiteBean.getTitre());
        serviceInscription.controlFrontActualite(actualiteBean.getInscription());
        // On retourne sur la fiche pour vérifier qu'on ne peut plus s'inscrire
        serviceActualite.viewContentDatagrid(actualiteBean.getTitre());
        serviceInscription.controlFrontMaxPlaceReached();
    }

    @Test
    @Exigence(ticketExigence = "KRTO-568", ticketTest = "KRTO-1094", enTantQue = RoleTest.ADMIN, jeVeux = "Ecrire un nouvelle entrée inscription depuis la fiche actualite", afinDe = "Vérifier l'authentification avant l'inscription")
    public void testInscriptionAuthNecessary() {
        actualiteBean.setInscription(fillInscriptionBeanAuthNecessary());
        actualiteBean.setTitre("Actualité pour inscription Authentifiée");
        serviceMenuBO.navigateToContenu(EnumExtension.ACTUALITE);
        serviceActualite.getScreenBO().createContent();
        serviceActualite.fillContent(actualiteBean);
        serviceInscription.fillSpecificContent(actualiteBean.getInscription());
        serviceActualite.publishContent();
        serviceActualite.viewContentDatagrid(actualiteBean.getTitre());
        serviceInscription.controlFrontActualite(actualiteBean.getInscription());
        // On retourne sur le backoffice
        this.init();
        serviceMenuBO.navigateToTools("enrollment", "MANAGE_ENROLLMENT", "HOME");
        serviceActualite.editContent(actualiteBean);
        serviceInscription.validateInscription(actualiteBean.getInscription());
    }

    private InscriptionBean fillInscriptionBeanAuthNecessary() {
        InscriptionBean inscriptionBean = fillInscriptionBean();
        inscriptionBean.setAuthentificationNecessaire(true);
        return inscriptionBean;
    }

    private InscriptionBean fillInscriptionBeanDateClose() {
        InscriptionBean inscriptionBean = fillInscriptionBean();
        inscriptionBean.setDateDebutInscription(DateUtils.getNowPlusDayMonthYearForDatePicker(-10L));
        inscriptionBean.setDateFinInscription(DateUtils.getNowPlusDayMonthYearForDatePicker(-3L));
        return inscriptionBean;
    }

    private InscriptionBean fillInscriptionBeanClose() {
        InscriptionBean inscriptionBean = fillInscriptionBean();
        inscriptionBean.setInscriptionOuverte(false);
        return inscriptionBean;
    }

    private InscriptionBean fillInscriptionBean() {
        InscriptionBean inscriptionBean = new InscriptionBean();
        inscriptionBean.setInscriptionOuverte(true);
        inscriptionBean.setAuthentificationNecessaire(false);
        inscriptionBean.setDateDebutInscription(DateUtils.getNowPlusDayMonthYearForDatePicker(-2L));
        inscriptionBean.setDateFinInscription(DateUtils.getNowPlusDayMonthYearForDatePicker(5L));
        inscriptionBean.setPlaceDisponible("10");
        inscriptionBean.setModeration(true);
        inscriptionBean.setEmailContact("mail@mail.fr");
        inscriptionBean.setNomResponsable("Responsable Inscription");
        inscriptionBean.setObjet("Objet Inscription");
        inscriptionBean.setMessage("Message Inscription");
        inscriptionBean.setNameInscription("John");
        inscriptionBean.setLastNameInscription("Doe");
        inscriptionBean.setMailInscription("john.doe@doe.com");
        inscriptionBean.setAdressInscription("08 Kervegan");
        inscriptionBean.setCityInscription("Nantes");
        inscriptionBean.setCpInscription("44000");
        inscriptionBean.setPhoneInscription("0102030405");
        return inscriptionBean;
    }

    private InscriptionBean fillInscriptionBeanMaxReached() {
        InscriptionBean inscriptionBean = fillInscriptionBean();
        inscriptionBean.setPlaceDisponible("1");
        return inscriptionBean;
    }
}
